==> mcg_extension-1.0.0.tar.gz: lib/extensions/intextension.dart <==
import 'dart:math';
import 'package:intl/intl.dart';

import '../constants.dart';

extension MyInt on int {
  String get makeKey {
    String text = '';
    do {
      text = '';
      for (var i = 0; i < this; i++) {
        text += keyCharacters[Random().nextInt(keyCharacters.length)];
      }
    } while (text.contains('mcg'));

    return text;
  }

  String get makeKeyFromNumber {
    var text = '';
    for (var i = 0; i < this; i++) {
      text += Random().nextInt(10).toString();
    }
    return text;
  }

  Duration get milliseconds => Duration(milliseconds: this);
  Duration get seconds => Duration(seconds: this);
  Duration get minutes => Duration(minutes: this);

  Future get wait => Future.delayed(milliseconds);

  /// gun - saat - dakika - saniye
  RemainingTime get remainingTime {
    final day = this ~/ 86400000;
    final hour = (this - day * 86400000) ~/ 3600000;
    final minute = (this - day * 86400000 - hour * 3600000) ~/ 60000;
    final second = (this - day * 86400000 - hour * 3600000 - minute * 60000) ~/ 1000;

    return RemainingTime(day, hour, minute, second);
  }

  int limit(int min, int max) {
    if (this > max) return max;
    if (this < min) return min;
    return this;
  }

  int maxLimit(int max) {
    if (this > max) return max;
    return this;
  }

  int minLimit(int min) {
    if (this < min) return min;
    return this;
  }

  int get random => Random().nextInt(this);

  ///timebloc yaz
  bool delayTimeFinish(String key) {
    return true;
  }

  ///"d-MMM, HH:mm"
  String dateFormat(String format) => DateFormat(format).format(dateTime);
  DateTime get dateTime => DateTime.fromMillisecondsSinceEpoch(this);
}

extension MyInt_ on int? {
  ///"d-MMM, HH:mm"
  String dateFormat(String format) => this == null ? '?' : DateFormat(format).format(dateTime);
  DateTime get dateTime => DateTime.fromMillisecondsSinceEpoch(this ?? 0);
}

class RemainingTime {
  int day;
  int hour;
  int minute;
  int second;
  RemainingTime(this.day, this.hour, this.minute, this.second);
}

==> mcg_extension-1.0.1.tar.gz: lib/extensions/intextension.dart <==
import 'dart:math';
import 'package:intl/intl.dart';

import '../constants.dart';
import 'datetimeextension.dart';

extension MyInt on int {
  String get makeKey {
    String text = '';
    do {
      text = '';
      for (var i = 0; i < this; i++) {
        text += keyCharacters[Random().nextInt(keyCharacters.length)];
      }
    } while (text.contains('mcg'));

    return text;
  }

  String get makeKeyFromNumber {
    var text = '';
    for (var i = 0; i < this; i++) {
      text += Random().nextInt(10).toString();
    }
    return text;
  }

  Duration get milliseconds => Duration(milliseconds: this);
  Duration get seconds => Duration(seconds: this);
  Duration get minutes => Duration(minutes: this);

  Future get wait => Future.delayed(milliseconds);

  /// gun - saat - dakika - saniye
  RemainingTime get remainingTime {
    final day = this ~/ 86400000;
    final hour = (this - day * 86400000) ~/ 3600000;
    final minute = (this - day * 86400000 - hour * 3600000) ~/ 60000;
    final second = (this - day * 86400000 - hour * 3600000 - minute * 60000) ~/ 1000;

    return RemainingTime(day, hour, minute, second);
  }

  int limit(int min, int max) {
    if (this > max) return max;
    if (this < min) return min;
    return this;
  }

  int maxLimit(int max) {
    if (this > max) return max;
    return this;
  }

  int minLimit(int min) {
    if (this < min) return min;
    return this;
  }

  int get random => Random().nextInt(this);

  ///timebloc yaz
  bool delayTimeFinish(String key) {
    return true;
  }

  ///"d-MMM, HH:mm"
  String dateFormat([String? format]) => DateFormat(format ?? DF.d_MMM_yyyy).format(dateTime);
  DateTime get dateTime => DateTime.fromMillisecondsSinceEpoch(this);
  // Saniye cinsinden degeri 09:00 gibi yapar
  String get timeToString => '${this ~/ 60}'.padLeft(2, '0') + ':' + '${this % 60}'.padLeft(2, '0');
}

extension MyInt_ on int? {
  ///"d-MMM, HH:mm"
  String dateFormat([String? format]) => this == null ? '?' : DateFormat(format ?? DF.d_MMM_yyyy).format(dateTime);
  DateTime get dateTime => DateTime.fromMillisecondsSinceEpoch(this ?? 0);
}

class RemainingTime {
  int day;
  int hour;
  int minute;
  int second;
  RemainingTime(this.day, this.hour, this.minute, this.second);
}
